<?php
/*
 * Pozivi funnkicije:
 * $dp = get_opcine();                              - vraća sve doprinose poreze
 * $dp = get_opcine($datumObracuna);                - vraća doprinose poreze koji su aktivni za datumObračuna
 * $dp = get_opcine($datumObracuna, 'naDohodak');  - vraća poreze koji su aktivni za datumObračuna
 * $dp = get_opcine($datumObracuna, 'izPlace');    - vraća doprinosi iz plaće koji su aktivni za datumObračuna
 * $dp = get_opcine($datumObracuna, 'naPlacu');    - vraća doprinosi na plaću koji su aktivni za datumObračuna
 * $danas = new DateTime();
 * $dp = get_opcine($danas->format('d.m.Y'));       - vraća trenutno aktivne doprinose poreze
 * 
 */
function get_opcine($datum='', $opcinaIliGrad='') {
    global $db;
    $query = " 
SELECT o1.*, vrijediDo
FROM opcine as o1
JOIN 
( 
    SELECT 
     o.`kodOpcine`, o.`vrijediOd`, 
    IF(NULL, NULL, DATE_SUB(min(o2.`vrijediOd`), INTERVAL 1 DAY)) as vrijediDo
    FROM opcine as o
    LEFT OUTER JOIN opcine AS o2
    ON o.`kodOpcine`=o2.`kodOpcine` and o.`vrijediOd`< o2.`vrijediOd`
    GROUP BY o.`kodOpcine`, o.`vrijediOd`
) AS oDo ON oDo.kodOpcine=o1.kodOpcine AND oDo.vrijediOd=o1.vrijediOd
WHERE (:datum='' OR :datum between o1.vrijediOd and IFNULL(vrijediDo,'3000-01-01'))
AND (:opcinaIliGrad='' OR o1.opcinaIliGrad=:opcinaIliGrad)
    ";
    if($datum!='') {
        $d = new DateTime($datum);
        $datum=$d->format("Y-m-d");
    }
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':datum', $datum);
        $statement->bindValue(':opcinaIliGrad', $opcinaIliGrad);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

/*
 * Funkcija dohvaća doprinos/porez koji vrijedi za zadani datum
 * Na primjer, ako imamo:
 * vrsta  vrijediOd naziv       stopa     IBAN ...
 * ---------------------------------------------------- 
 * porez1 01.01.2000 Stopa(24%) 24.00000  17500.00 ...
 * porez1 01.01.2019 Stopa(24%) 24.00000  35000.00 ...
 * 
 * poziv: 
 *   $porez=get_doprinosPorez_za_datum('porez1','23.12.2018'):
 * vraća slog:
 * porez1 01.01.2000 Stopa(24%) 24.00000  17500.00 ...
 * a poziv: 
 *   $porez=get_doprinosPorez_za_datum('porez1','15.01.2019'):
 * vraća slog:
 * porez1 01.01.2019 Stopa(24%) 24.00000  35000.00 ...
 */
function get_opcine_po_nazivu($kodOpcine='') {
    global $db;
    $query = " 
SELECT distinct kodOpcine, nazivOpcine from opcine
WHERE kodOpcine = :kodOpcine or :kodOpcine=''
ORDER BY nazivOpcine
";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodOpcine', $kodOpcine);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_prirez_za_datum($kodOpcine,$datum='') {
    global $db;
    $query = " 
SELECT o1.*, vrijediDo
FROM opcine as o1
JOIN 
( 
    SELECT 
     o.`kodOpcine`, o.`vrijediOd`, 
    IF(NULL, NULL, DATE_SUB(min(o2.`vrijediOd`), INTERVAL 1 DAY)) as vrijediDo
    FROM opcine as o
    LEFT OUTER JOIN opcine AS o2
    ON o.`kodOpcine`=o2.`kodOpcine` and o.`vrijediOd`< o2.`vrijediOd`
    GROUP BY o.`kodOpcine`, o.`vrijediOd`
) AS dDo ON dDo.kodOpcine=o1.kodOpcine AND dDo.vrijediOd=o1.vrijediOd
WHERE o1.kodOpcine=:kodOpcine
AND (:datum between o1.vrijediOd and IFNULL(vrijediDo,'3000-01-01'))
    ";
    if($datum!='') {
        $d = new DateTime($datum);
        $datum=$d->format("Y-m-d");
    } else {
        $d = new DateTime();
        $datum=$d->format("Y-m-d");
    }
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodOpcine', $kodOpcine);
        $statement->bindValue(':datum', $datum);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_jedan_prirez($kodOpcine,$vrijediOd) {
    global $db;
    $query = " 
    SELECT *
    FROM opcine 
    WHERE kodOpcine=:kodOpcine
    AND vrijediOd=:vrijediOd
    ";

    $d = new DateTime($vrijediOd);
    $vrijediOd=$d->format("Y-m-d");
    
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodOpcine', $kodOpcine);
        $statement->bindValue(':vrijediOd', $vrijediOd);
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function get_jedna_opcina($kodOpcine) {
    global $db;
    $query = " 
    SELECT distinct kodOpcine, nazivOpcine
    FROM opcine 
    WHERE kodOpcine=:kodOpcine  
    ";

    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodOpcine', $kodOpcine);       
        $statement->execute();
        $result = $statement->fetch();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function add_opcine($slog) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = " 
        INSERT INTO opcine
        (
         kodOpcine,
         nazivOpcine,           
         vrijediOd,
         stopaPrireza,
         opcinaIliGrad,
         IBAN,
         datumIzmjene,
         tkoJeIzmjenio
        )    
        VALUES
        (
         :kodOpcine,
         :nazivOpcine,           
         :vrijediOd,
         :stopaPrireza,
         :opcinaIliGrad,
         :IBAN,
         NOW(),
         :email_user
        )
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodOpcine', $slog['kodOpcine']);
        $statement->bindValue(':nazivOpcine', $slog['nazivOpcine']);
        $d = new DateTime($slog['vrijediOd']);
        $statement->bindValue(':vrijediOd', $d->format("Y-m-d"));
        $statement->bindValue(':stopaPrireza', str_replace(',', '.', $slog['stopaPrireza']));
        $statement->bindValue(':opcinaIliGrad', $slog['opcinaIliGrad']);
        $statement->bindValue(':IBAN', str_replace(',', '.', $slog['IBAN']));
        $statement->bindValue(':email_user', $email_user); 
        $statement->execute();
        $statement->closeCursor();      
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function update_opcine($slog, $stariKljuc) {
    global $db;
	$email_user = $_SESSION['admin']['email'];
    $query = " 
        UPDATE opcine
        SET nazivOpcine = :nazivOpcine,           
            vrijediOd = :vrijediOd,
            stopaPrireza = :stopaPrireza,
            opcinaIliGrad = :opcinaIliGrad,
            IBAN = :IBAN,
            datumIzmjene = NOW(),
            tkoJeIzmjenio = :email_user
        WHERE kodOpcine = :kodOpcine_st
        AND vrijediOd = :vrijediOd_st
        ";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':nazivOpcine', $slog['nazivOpcine']);
        $d = new DateTime($slog['vrijediOd']);
        $statement->bindValue(':vrijediOd', $d->format("Y-m-d"));
        $statement->bindValue(':stopaPrireza', str_replace(',', '.', $slog['stopaPrireza']));
        $statement->bindValue(':opcinaIliGrad', $slog['opcinaIliGrad']);
        $statement->bindValue(':IBAN', str_replace(',', '.', $slog['IBAN']));
        $statement->bindValue(':email_user', $email_user); 
        $statement->bindValue(':kodOpcine_st', $stariKljuc['kodOpcine']);
        $d = new DateTime($stariKljuc['vrijediOd']);
        $statement->bindValue(':vrijediOd_st', $d->format("Y-m-d"));
        $statement->execute();
        $statement->closeCursor();      
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}

function delete_opcine($kodOpcine, $vrijediOd) {
    global $db;
    $query = "DELETE FROM opcine WHERE kodOpcine = :kodOpcine AND vrijediOd=:vrijediOd";
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodOpcine', $kodOpcine);
        $d = new DateTime($vrijediOd);
        $statement->bindValue(':vrijediOd', $d->format("Y-m-d"));
        $statement->execute();
        $statement->closeCursor();
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    }
}
function get_radnici_po_opcinama($kodOpcine='',$datum='') {
    global $db;
    $query = " 
SELECT o1.*, vrijediDo, r.kodRadnika, r.imeIprezime
FROM opcine as o1
JOIN maticna_radnika AS r ON o1.kodOpcine = r.opcinaPrebivalista
JOIN 
( 
    SELECT 
     o.`kodOpcine`, o.`vrijediOd`, 
    IF(NULL, NULL, DATE_SUB(min(o2.`vrijediOd`), INTERVAL 1 DAY)) as vrijediDo
    FROM opcine as o
    LEFT OUTER JOIN opcine AS o2
    ON o.`kodOpcine`=o2.`kodOpcine` and o.`vrijediOd`< o2.`vrijediOd`
    GROUP BY o.`kodOpcine`, o.`vrijediOd`
) AS dDo ON dDo.kodOpcine=o1.kodOpcine AND dDo.vrijediOd=o1.vrijediOd
WHERE (:kodOpcine = '' OR (o1.kodOpcine=:kodOpcine AND r.opcinaPrebivalista =:kodOpcine))
AND (:datum between o1.vrijediOd and IFNULL(vrijediDo,'3000-01-01'))        
order by o1.nazivOpcine, r.imeIprezime, r.kodRadnika
    ";  
    if($datum!='') {
        $d = new DateTime($datum);
        $datum=$d->format("Y-m-d");
    } else {
        $d = new DateTime();
        $datum=$d->format("Y-m-d");
    }
    try {
        $statement = $db->prepare($query);
        $statement->bindValue(':kodOpcine', $kodOpcine);
        $statement->bindValue(':datum', $datum);
        $statement->execute();
        $result = $statement->fetchAll();
        $statement->closeCursor();
        return $result;
    } catch (PDOException $e) {
        $error_message = $e->getMessage();
        display_db_error($error_message);
    } 
}
?>